/**
 * @file avatar.c Galago Avatar message processor
 *
 * Copyright (C) 2004-2005 Christian Hammond.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 */
#include "filter.h"

static DBusHandlerResult
avatar_set_image(DBusConnection *dbus_conn, DBusMessage *message,
				 GalagodCoCo *coco, GalagoAvatar *avatar)
{
	DBusMessageIter iter;
	unsigned char *image_data;
	int image_len;

	dbus_message_iter_init(message, &iter);
	galago_dbus_message_iter_get_byte_array(&iter, &image_data, &image_len);

	galago_avatar_set_image_data(avatar, image_data, image_len);

#if !GALAGO_CHECK_DBUS_VERSION(0, 30)
	dbus_free(image_data);
#endif

	return DBUS_HANDLER_RESULT_HANDLED;
}

static const GalagodCommand commands[] =
{
	GALAGOD_COMMAND("SetImage", avatar_set_image),
	GALAGOD_COMMAND_LAST
};

void
galagod_avatar_add_filter(GalagoAvatar *avatar)
{
	galagod_filters_add(avatar, commands, GALAGO_DBUS_AVATAR_INTERFACE);
}

void
galagod_avatar_remove_filter(GalagoAvatar *avatar)
{
	galagod_filters_remove(avatar);
}
