/**
 * @file meta-object.c MetaObject API
 *
 * Copyright (C) 2004-2005 Christian Hammond.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 */
#include <glib.h>
#include "meta-object.h"

GALAGO_REGISTER_CLASS(galagod_meta_object, GalagodMetaObject, NULL, NULL);

static void
galagod_meta_object_finalize(GalagoObject *object)
{
	GalagodMetaObjectClass *klass;
	GalagodMetaObject *meta_object = (GalagodMetaObject *)object;

	klass = (GalagodMetaObjectClass *)GALAGO_OBJECT_CLASS(meta_object);

	if (meta_object->main_object != NULL)
	{
		if (klass->remove_filter != NULL)
			klass->remove_filter(meta_object->main_object);

		galago_object_unref(meta_object->main_object);
	}

	if (meta_object->children != NULL)
	{
		const GalagoList *l;

		for (l = meta_object->children; l != NULL; l = l->next)
			galago_object_set_data(l->data, "meta-object", NULL);

		galago_list_destroy(meta_object->children);
	}
};

static void
galagod_meta_object_dbus_message_append(DBusMessageIter *iter,
										const GalagoObject *object)
{
	GalagodMetaObject *meta_object = (GalagodMetaObject *)object;

	galago_dbus_message_iter_append_object(iter, meta_object->main_object);
}

static void
galagod_meta_object_class_init(GalagoObjectClass *klass)
{
	GalagodMetaObjectClass *meta_klass;

	meta_klass = (GalagodMetaObjectClass *)klass;

	klass->finalize            = galagod_meta_object_finalize;
	klass->dbus_message_append = galagod_meta_object_dbus_message_append;

	meta_klass->add_filter    = NULL;
	meta_klass->remove_filter = NULL;
}

static void
galagod_meta_object_object_init(GalagodMetaObject *meta_object)
{
	meta_object->main_object = NULL;
	meta_object->children    = NULL;
};

void *
galagod_meta_account_get_main_object(const GalagodMetaObject *meta_object)
{
	galago_return_val_if_fail(meta_object != NULL,           NULL);
	galago_return_val_if_fail(GALAGO_IS_OBJECT(meta_object), NULL);

	return meta_object->main_object;
}

const GalagoList *
galagod_meta_objects_get_children(const GalagodMetaObject *meta_object)
{
	galago_return_val_if_fail(meta_object != NULL,           NULL);
	galago_return_val_if_fail(GALAGO_IS_OBJECT(meta_object), NULL);

	return meta_object->children;
}

void
galagod_meta_object_add_child(GalagodMetaObject *meta_object, void *object)
{
	galago_return_if_fail(meta_object != NULL);
	galago_return_if_fail(GALAGO_IS_OBJECT(meta_object));

	/* TODO: Class check. */

	meta_object->children = galago_list_append(meta_object->children, object);
}

void
galagod_meta_object_remove_child(GalagodMetaObject *meta_object, void *object)
{
	galago_return_if_fail(meta_object != NULL);
	galago_return_if_fail(GALAGO_IS_OBJECT(meta_object));

	/* TODO: Class check. */

	meta_object->children = galago_list_remove(meta_object->children, object);
}
