/**
 * @file photo.c Galago Photo message processor
 *
 * Copyright (C) 2004-2005 Christian Hammond.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 */
#include "filter.h"

static DBusHandlerResult
photo_set_image(DBusConnection *dbus_conn, DBusMessage *message,
				GalagodCoCo *coco, GalagoPhoto *photo)
{
	DBusMessageIter iter;
	unsigned char *image_data;
	int image_len;

	dbus_message_iter_init(message, &iter);
	galago_dbus_message_iter_get_byte_array(&iter, &image_data, &image_len);

	galago_photo_set_image_data(photo, image_data, image_len);

#if !GALAGO_CHECK_DBUS_VERSION(0, 30)
	dbus_free(image_data);
#endif

	return DBUS_HANDLER_RESULT_HANDLED;
}

static const GalagodCommand commands[] =
{
	GALAGOD_COMMAND("SetImage", photo_set_image),
	GALAGOD_COMMAND_LAST
};

void
galagod_photo_add_filter(GalagoPhoto *photo)
{
	galagod_filters_add(photo, commands, GALAGO_DBUS_PHOTO_INTERFACE);
}

void
galagod_photo_remove_filter(GalagoPhoto *photo)
{
	galagod_filters_remove(photo);
}
